@@ -7,5 +7,5 @@ def clear_console(type="full"):
         else:
             system("clear")
     elif type == "line":
-        print(100*" ",end="\r\r")
+        print("\033[A\033[K", end="") #presunutie o poličko spať "\033[A", zmazanie riadka "\033[K"
     
\ No newline at end of file
